import { App, createVNode } from 'vue'

import SvgIcon from './index.vue'

/**
 * 注意:
 * import.meta.glob 是 Vite 从文件系统导入多个模块  https://vitejs.cn/guide/features.html#glob-import
 * ./svg/*.svg  是导入模块的位置相对路径
 * 后面截取名称中 slice(6,···) 6 代表 ./svg/ 的长度为 6
 * 所以：如果修改了目录，需要同步修改这个值
 */
const SvgComponents = import.meta.glob('../assets/svg/*.svg')

// Svg 全局注册
export default {
    install(app: App) {
        // 默认也把 SvgIcon 组件注册了
        app.component('SvgIcon', SvgIcon)

        // 循环注册每一个svg
        for (let component in SvgComponents) {
            // 因为导入的是 svg 他的键是路径，所以需要截取他的名称  ！！注意 6 是 SvgComponents 相对路径下的前6个字符
            const name = component.slice(14, component.indexOf('.svg'))

            app.component(name, createVNode(SvgIcon, { name: name }))
        }
    }
}
